@@ -136,20 +136,12 @@ class PSMTemplate():
         :param padding_bottom: bottom padding, defaults to 0.0
         :type padding_bottom: float, optional
         """
-        with pkg_resources.path('static','ARIAL.ttf') as p:
-            self.ARIAL_FONT_PATH = p.__str__()
+        self.ARIAL_FONT_PATH = os.path.join(os.path.dirname(__file__), 'static', 'ARIAL.ttf')
+        self.PSM_Logo_Path = os.path.join(os.path.dirname(__file__), 'static', 'PSM Logo.jpg')
+        os.environ["MATPLOTLIBRC"] = os.path.join(os.path.dirname(__file__), 'static', 'matplotlibrc')
 
-        
-        with pkg_resources.path('static',"PSM Logo.jpg") as p:
-            self.PSM_Logo_Path = p
-
-
-        print(self.ARIAL_FONT_PATH)
         registerFont(TTFont('Arial',self.ARIAL_FONT_PATH))
 
-        with pkg_resources.path('static','matplotlibrc') as p:
-            os.environ["MATPLOTLIBRC"] = p.__str__()
-
         self.doc = SimpleDocTemplate(file_name,pagesize=page_size)
         self.canvas = canvas.Canvas(file_name,page_size)
         self.page_width,self.page_height = [size/cm for size in page_size]
